.. :changelog:

History
-------

0.9.0 (2013-11-08)
++++++++++++++++++

* First implementation

0.9.0.post1 (2013-11-08)
++++++++++++++++++

* Fixed PyPI classifiers

0.9.1 (2013-11-14)
++++++++++++++++++

* Added a direct import of DictRegister in __init__.py (thanks to https://github.com/Jeff17Robbins)

0.9.2 (2013-11-14)
++++++++++++++++++

* Fixed import in __init__.py for Python 3, now all tox tests pass

1.0.0 (2013-12-04)
++++++++++++++++++

* Raise TypeError instead of ValueError if invalid object is passed (pull request from joshgeller)
